==> haskell-th-desugar1.11-1.11-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-desugar1.11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-desugar
version:              1.11
visibility:           public
id:                   th-desugar-1.11-8uqiynkWJEpAHXSruCEVnh
key:                  th-desugar-1.11-8uqiynkWJEpAHXSruCEVnh
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Richard Eisenberg <rae@cs.brynmawr.edu>
stability:            experimental
homepage:             https://github.com/goldfirere/th-desugar
synopsis:             Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.

category:             Template Haskell
abi:                  a46ccf817709be2f84a5866b027f857f
exposed:              True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.OMap
    Language.Haskell.TH.Desugar.OMap.Strict
    Language.Haskell.TH.Desugar.OSet Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten

hidden-modules:
    Language.Haskell.TH.Desugar.AST Language.Haskell.TH.Desugar.Core
    Language.Haskell.TH.Desugar.FV Language.Haskell.TH.Desugar.Match
    Language.Haskell.TH.Desugar.Reify Language.Haskell.TH.Desugar.Util

import-dirs:          /usr/lib/ghc-8.10.4/site-local/th-desugar-1.11
library-dirs:         /usr/lib/ghc-8.10.4/site-local/th-desugar-1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/th-desugar-1.11
hs-libraries:         HSth-desugar-1.11-8uqiynkWJEpAHXSruCEVnh
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-prim-0.6.1 mtl-2.2.2
    ordered-containers-0.2.2-GyU6swLq6k0DcCVw8rbPro
    syb-0.7.2.1-IHzu7I6ikCoGwAbnu6OBXz template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG
    th-orphans-0.13.11-8NhbtB8xkhm5XgH2hGe10A
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:
    /usr/share/doc/haskell-th-desugar1.11/html/th-desugar.haddock

haddock-html:         /usr/share/doc/haskell-th-desugar1.11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-desugar1.11-1.11-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-desugar1.11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-desugar
version:              1.11
visibility:           public
id:                   th-desugar-1.11-2E1KBC78SXWGCMIzk5Bl6D
key:                  th-desugar-1.11-2E1KBC78SXWGCMIzk5Bl6D
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Richard Eisenberg <rae@cs.brynmawr.edu>
stability:            experimental
homepage:             https://github.com/goldfirere/th-desugar
synopsis:             Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.

category:             Template Haskell
abi:                  dab7bb30ee61bc814f797ed645892279
exposed:              True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.OMap
    Language.Haskell.TH.Desugar.OMap.Strict
    Language.Haskell.TH.Desugar.OSet Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten

hidden-modules:
    Language.Haskell.TH.Desugar.AST Language.Haskell.TH.Desugar.Core
    Language.Haskell.TH.Desugar.FV Language.Haskell.TH.Desugar.Match
    Language.Haskell.TH.Desugar.Reify Language.Haskell.TH.Desugar.Util

import-dirs:          /usr/lib/ghc-8.10.4/site-local/th-desugar-1.11
library-dirs:         /usr/lib/ghc-8.10.4/site-local/th-desugar-1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/th-desugar-1.11
hs-libraries:         HSth-desugar-1.11-2E1KBC78SXWGCMIzk5Bl6D
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-prim-0.6.1 mtl-2.2.2
    ordered-containers-0.2.2-GyU6swLq6k0DcCVw8rbPro
    syb-0.7.2.1-IHzu7I6ikCoGwAbnu6OBXz template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG
    th-orphans-0.13.11-J9338ReQ0djpQ6ickYokQ
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:
    /usr/share/doc/haskell-th-desugar1.11/html/th-desugar.haddock

haddock-html:         /usr/share/doc/haskell-th-desugar1.11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
